==> portal-contribuinte-3.096.2.zip: BOOT-INF/classes/sql/simam/referenciaOrigemParcelamentoDABatch.sql <==
insert into tcedebitoinsccreditoda(iddebitoparcelareceita,valor,idTceInscCreditoDA)
select distinct
  iddebitoparcelareceita,
  valor, idTceInscCreditoDA
from 
  ( 
  select
    dpr.iddebitoparcelareceita,
    0 as valor,
    (
    select 
      min(distinct tic.idtceinsccreditoda) 
    from tribdebitoparcelareceita dpro
    join tribreceita tro on tro.entidade = :entidade
    	and tro.exercicio = :exercicio
      	and tro.receita = dpro.receita
    join tribreceitatipo trto on trto.tiporeceita = tro.tiporeceita
    join tcedebitoinsccreditoda ld on ld.iddebitoparcelareceita  = dpro.iddebitoparcelareceita
    join tceinsccreditoda tic on tic.idtceinsccreditoda = ld.idtceinsccreditoda
    where
      dpro.entidade = d.entidade
      and dpro.exercicio = d.exercicio
      and dpro.tipocadastro = d.tipocadastro
      and dpro.cadastrogeral = d.cadastrogeral
      and dpro.guiarecolhimento = d.guiarecolhimento
      and dpro.subdivida = d.subdivida
      and trto.classificacaoreceitatipo = trt.classificacaoreceitatipo) idTceInscCreditoDA
  from tribparcelamento p
  join tribparcelamentodebitoorigem pd on p.idparcelamento = pd.idparcelamento
  join tribdebito d on d.iddebito = pd.iddebito
  join tribdebito dn on dn.iddebito = pd.iddebitonovo
  join tribdebitoparcelareceita dpr on
    dpr.entidade = dn.entidade
    and dpr.exercicio = dn.exercicio
    and dpr.tipocadastro = dn.tipocadastro
    and dpr.cadastrogeral = dn.cadastrogeral
    and dpr.guiarecolhimento = dn.guiarecolhimento
    and dpr.subdivida = dn.subdivida
  join tribreceita tr on
    tr.entidade = :entidade
    and tr.exercicio = :exercicio
    and tr.receita = dpr.receita
  join tribreceitatipo trt on trt.tiporeceita = tr.tiporeceita
  join tribclassificacaoreceitatipo tcrt on tcrt.classificacaoreceitatipo = trt.classificacaoreceitatipo
  where
    trt.classificacaoreceitatipo in (1, 2, 3, 4, 5, 7)
    and p.dataparcelamento between :dataInicial and :dataFinal
union all
  select
    dpr.iddebitoparcelareceita,
    0 as valor,
    (
    select
      min(distinct tic.idtceinsccreditoda)
    from tribdebitoparcelareceita dpro
    left join tribreceita tro on
      tro.entidade = :entidade
      and tro.exercicio = :exercicio
      and tro.receita = dpro.receita
    left join tribreceitatipo trto on trto.tiporeceita = tro.tiporeceita
    left join tcedebitoinsccreditoda ld on ld.iddebitoparcelareceita = dpro.iddebitoparcelareceita
    left join tceinsccreditoda tic on tic.idtceinsccreditoda = ld.idtceinsccreditoda
    where
      dpro.entidade = d.entidade
      and dpro.exercicio = d.exercicio
      and dpro.tipocadastro = d.tipocadastro
      and dpro.cadastrogeral = d.cadastrogeral
      and dpro.guiarecolhimento = d.guiarecolhimento
      and dpro.subdivida = d.subdivida
      and trto.classificacaoreceitatipo = trt.classificacaoreceitatipo) idTceInscCreditoDA
  from tribestornoparcelamento ep
  join tribestornoparcelamentodebito epd on ep.idestornoparcelamento = epd.idestornoparcelamento
  join tribdebito d on d.iddebito = epd.iddebitoorigem
  join tribdebito dn on dn.iddebito = epd.iddebitodestino
  join tribdebitoparcelareceita dpr on
    dpr.entidade = dn.entidade
    and dpr.exercicio = dn.exercicio
    and dpr.tipocadastro = dn.tipocadastro
    and dpr.cadastrogeral = dn.cadastrogeral
    and dpr.guiarecolhimento = dn.guiarecolhimento
    and dpr.subdivida = dn.subdivida
  left join tribreceita tr on
    tr.entidade = :entidade
    and tr.exercicio = :exercicio
    and tr.receita = dpr.receita
  join tribreceitatipo trt on trt.tiporeceita = tr.tiporeceita
  join tribclassificacaoreceitatipo tcrt on tcrt.classificacaoreceitatipo = trt.classificacaoreceitatipo
  where
    trt.classificacaoreceitatipo in (1, 2, 3, 4, 5, 7)
    and ep.dataestorno between :dataInicial and :dataFinal) x
where x.idTceInscCreditoDA is not null
  and not exists(select 1 from tceDebitoInscCreditoDA tdic_Destino
    			  where tdic_Destino.iddebitoparcelareceita = x.iddebitoparcelareceita)

==> portal-contribuinte-3.190.1.zip: BOOT-INF/classes/sql/simam/referenciaOrigemParcelamentoDABatch.sql <==
insert into tcedebitoinsccreditoda(iddebitoparcelareceita,valor,idTceInscCreditoDA)
select distinct
  iddebitoparcelareceita,
  valor, idTceInscCreditoDA
from 
  ( 
  select
    dpr.iddebitoparcelareceita,
    0 as valor,
    (
    select 
      min(distinct tic.idtceinsccreditoda) 
    from tribdebitoparcelareceita dpro
    join tribreceita tro on tro.entidade = :entidade
    	and tro.exercicio = :exercicio
      	and tro.receita = dpro.receita
    join tribreceitatipo trto on trto.tiporeceita = tro.tiporeceita
    join tcedebitoinsccreditoda ld on ld.iddebitoparcelareceita  = dpro.iddebitoparcelareceita
    join tceinsccreditoda tic on tic.idtceinsccreditoda = ld.idtceinsccreditoda
    where
      dpro.entidade = d.entidade
      and dpro.exercicio = d.exercicio
      and dpro.tipocadastro = d.tipocadastro
      and dpro.cadastrogeral = d.cadastrogeral
      and dpro.guiarecolhimento = d.guiarecolhimento
      and dpro.subdivida = d.subdivida
      and trto.classificacaoreceitatipo = trt.classificacaoreceitatipo) idTceInscCreditoDA
  from tribparcelamento p
  join tribparcelamentodebitoorigem pd on p.idparcelamento = pd.idparcelamento
  join tribdebito d on d.iddebito = pd.iddebito
  join tribdebito dn on dn.iddebito = pd.iddebitonovo
  join tribdebitoparcelareceita dpr on
    dpr.entidade = dn.entidade
    and dpr.exercicio = dn.exercicio
    and dpr.tipocadastro = dn.tipocadastro
    and dpr.cadastrogeral = dn.cadastrogeral
    and dpr.guiarecolhimento = dn.guiarecolhimento
    and dpr.subdivida = dn.subdivida
  join tribreceita tr on
    tr.entidade = :entidade
    and tr.exercicio = :exercicio
    and tr.receita = dpr.receita
  join tribreceitatipo trt on trt.tiporeceita = tr.tiporeceita
  join tribclassificacaoreceitatipo tcrt on tcrt.classificacaoreceitatipo = trt.classificacaoreceitatipo
  where
    trt.classificacaoreceitatipo in (1, 2, 3, 4, 5, 7)
    and p.dataparcelamento between :dataInicial and :dataFinal
union all
  select
    dpr.iddebitoparcelareceita,
    0 as valor,
    (
    select
      min(distinct tic.idtceinsccreditoda)
    from tribdebitoparcelareceita dpro
    left join tribreceita tro on
      tro.entidade = :entidade
      and tro.exercicio = :exercicio
      and tro.receita = dpro.receita
    left join tribreceitatipo trto on trto.tiporeceita = tro.tiporeceita
    left join tcedebitoinsccreditoda ld on ld.iddebitoparcelareceita = dpro.iddebitoparcelareceita
    left join tceinsccreditoda tic on tic.idtceinsccreditoda = ld.idtceinsccreditoda
    where
      dpro.entidade = d.entidade
      and dpro.exercicio = d.exercicio
      and dpro.tipocadastro = d.tipocadastro
      and dpro.cadastrogeral = d.cadastrogeral
      and dpro.guiarecolhimento = d.guiarecolhimento
      and dpro.subdivida = d.subdivida
      and trto.classificacaoreceitatipo = trt.classificacaoreceitatipo) idTceInscCreditoDA
  from tribestornoparcelamento ep
  join tribestornoparcelamentodebito epd on ep.idestornoparcelamento = epd.idestornoparcelamento
  join tribdebito d on d.iddebito = epd.iddebitoorigem
  join tribdebito dn on dn.iddebito = epd.iddebitodestino
  join tribdebitoparcelareceita dpr on
    dpr.entidade = dn.entidade
    and dpr.exercicio = dn.exercicio
    and dpr.tipocadastro = dn.tipocadastro
    and dpr.cadastrogeral = dn.cadastrogeral
    and dpr.guiarecolhimento = dn.guiarecolhimento
    and dpr.subdivida = dn.subdivida
  left join tribreceita tr on
    tr.entidade = :entidade
    and tr.exercicio = :exercicio
    and tr.receita = dpr.receita
  join tribreceitatipo trt on trt.tiporeceita = tr.tiporeceita
  join tribclassificacaoreceitatipo tcrt on tcrt.classificacaoreceitatipo = trt.classificacaoreceitatipo
  where
    trt.classificacaoreceitatipo in (1, 2, 3, 4, 5, 7)
    and ep.dataestorno between :dataInicial and :dataFinal
union all
  select tdpr_destino.iddebitoparcelareceita, 0 as valor, tdida.idtceinsccreditoda
  from tribpgtonegociado tpn
           left join tribpgtonegociadodebitonovo tpndn on tpn.pgtonegociado = tpndn.pgtonegociado
           left join tribdebitoparcelareceita tdpr_origem
                     on tdpr_origem.entidade = tpndn.entidadeorigem and tdpr_origem.exercicio = tpndn.exercicioorigem
                         and tdpr_origem.tipocadastro = tpndn.tipocadastroorigem and tdpr_origem.cadastrogeral = tpndn.cadastrogeralorigem
                         and tdpr_origem.guiarecolhimento = tpndn.guiarecolhimentoorigem and tdpr_origem.subdivida = tpndn.subdividaorigem
                         and tdpr_origem.parcela = tpndn.parcelaorigem
           left join tribdebitoparcelareceita tdpr_destino
                     on tdpr_destino.entidade = tpndn.entidadedestino and tdpr_destino.exercicio = tpndn.exerciciodestino
                         and tdpr_destino.tipocadastro = tpndn.tipocadastrodestino and tdpr_destino.cadastrogeral = tpndn.cadastrogeraldestino
                         and tdpr_destino.guiarecolhimento = tpndn.guiarecolhimentodestino and tdpr_destino.subdivida = tpndn.subdividadestino
                         and tdpr_destino.parcela = tpndn.parceladestino and tdpr_origem.receita = tdpr_destino.receita
           left join tribdebitoparcela tdp_origem
                     on tdpr_origem.entidade = tdp_origem.entidade and tdpr_origem.exercicio = tdp_origem.exercicio
                         and tdpr_origem.tipocadastro = tdp_origem.tipocadastro and tdpr_origem.cadastrogeral = tdp_origem.cadastrogeral
                         and tdpr_origem.guiarecolhimento = tdp_origem.guiarecolhimento and tdpr_origem.subdivida = tdp_origem.subdivida
                         and tdpr_origem.parcela = tdp_origem.parcela
           left join tcedebitoinsccreditoda tdida on tdpr_origem.iddebitoparcelareceita = tdida.iddebitoparcelareceita
           left join tribreceita tr
                     on tr.entidade = :entidade and tr.exercicio = :exercicio and tr.receita = tdpr_destino.receita
           join tribreceitatipo trt on trt.tiporeceita = tr.tiporeceita
           join tribclassificacaoreceitatipo tcrt on tcrt.classificacaoreceitatipo = trt.classificacaoreceitatipo
  where trt.classificacaoreceitatipo in (1, 2, 3, 4, 5, 7)
    and tpn.datanegociacao between :dataInicial and :dataFinal
    and tdp_origem.situacaolegal in (1,2)
  ) x
where x.idTceInscCreditoDA is not null
  and not exists(select 1 from tceDebitoInscCreditoDA tdic_Destino
    			  where tdic_Destino.iddebitoparcelareceita = x.iddebitoparcelareceita)
